%-------------------------------------------------------------------------%
%                                                                         %
% Optical Transfer functions for Dual PD Amp -- measures the amplitude and
%   phase between the input and output signal through the board from      % 
%   the OZ Optics fiber couled laser                                      %
% Data from SR785                                                         %
%                                                                         %
%-------------------------------------------------------------------------%

%% Modulation Noise
data110 = importdata('SRS110.mat');

% shift to zero dB
maxdb = max(data110(:,2));
data110(:,2) = data110(:,2)-maxdb;


%% Board Side A:

% D0: Off, D1: Off (0dB)
data111 = importdata('SRS111.mat');
% D0: On, D1: Off (10dB)
data112 = importdata('SRS112.mat');
% D0: On, D1: On (20dB)
data113 = importdata('SRS113.mat');
% D0: Off, D1: On (30dB)
data114 = importdata('SRS114.mat');

% Account for laser modulation
data111(:,2) = data111(:,2) - data110(:,2);
data112(:,2) = data112(:,2) - data110(:,2);
data113(:,2) = data113(:,2) - data110(:,2);
data114(:,2) = data114(:,2) - data110(:,2);
data111(:,3) = data111(:,3) - data110(:,3);
data112(:,3) = data112(:,3) - data110(:,3);
data113(:,3) = data113(:,3) - data110(:,3);
data114(:,3) = data114(:,3) - data110(:,3);


%% Board Side B:

% D0: Off, D1: Off (0dB)
data115 = importdata('SRS115.mat');
% D0: On, D1: Off (10dB)
data116 = importdata('SRS116.mat');
% D0: On, D1: On (20dB)
data117 = importdata('SRS117.mat');
% D0: Off, D1: On (30dB)
data118 = importdata('SRS118.mat');

% Account for laser modulation
data115(:,2) = data115(:,2) - data110(:,2);
data116(:,2) = data116(:,2) - data110(:,2);
data117(:,2) = data117(:,2) - data110(:,2);
data118(:,2) = data118(:,2) - data110(:,2);
data115(:,3) = data115(:,3) - data110(:,3);
data116(:,3) = data116(:,3) - data110(:,3);
data117(:,3) = data117(:,3) - data110(:,3);
data118(:,3) = data118(:,3) - data110(:,3);

%% Side B Plots
figure(1);
subplot(2,1,1)
semilogx(data115(94:800,1), data115(94:800,2),data116(94:800,1), data116(94:800,2),data117(94:800,1), data117(94:800,2),data118(94:800,1), data118(94:800,2));
legend('-- gain', '+- gain', '++ gain', '-+ gain');
title('Amplitude Optical Transfer Functions of side B');
xlabel('Hz');
ylabel('dB');
grid;
subplot(2,1,2)
semilogx(data115(94:800,1), unwrap(data115(94:800,3)),data116(94:800,1), unwrap(data116(94:800,3)),data117(94:800,1), unwrap(data117(94:800,3)),data118(94:800,1), unwrap(data118(94:800,3)));
legend('-- gain', '+- gain', '++ gain', '-+ gain');
title('Phase Opical Transfer Functions of side B');
xlabel('Hz');
ylabel('Deg');
grid;


%% Side A Plot
figure (2)
subplot(2,1,1)
semilogx(data111(82:800,1), data111(82:800,2),data112(82:800,1), data112(82:800,2),data113(82:800,1), data113(82:800,2),data114(82:800,1), data114(82:800,2));
legend('-- gain', '+- gain', '++ gain', '-+ gain');
title('Amplitude Optical Transfer Functions of side A');
xlabel('Hz');
ylabel('dB');
grid;
subplot(2,1,2)
semilogx(data111(82:800,1), unwrap(data111(82:800,3)),data112(82:800,1), unwrap(data112(82:800,3)),data113(82:800,1), unwrap(data113(82:800,3)),data114(82:800,1), unwrap(data114(82:800,3)));
legend('-- gain', '+- gain', '++ gain', '-+ gain');
title('Phase Optical Transfer Functions of side A');
xlabel('Hz');
ylabel('Deg');
grid;


%% Comparison with Optical and Electric Transfer Function
% data pulled from Tranfer Function folder (TF.m)

figure(3)
subplot(2,1,1)
semilogx(data114(82:800,1), data114(82:800,2),data08(22:200,1), data08(22:200,2));
legend('Optical', 'Electrical');
title('Amplitude Transfer Functions for -x gain settings of side A');
xlabel('Hz');
ylabel('dB');
grid;
subplot(2,1,2)
semilogx(data114(82:800,1), unwrap(data114(82:800,3)),data08(22:200,1), data08(22:200,3));
legend('Optical', 'Electrical');
title('Phase Transfer Functions for -x gain settings of side A');
xlabel('Hz');
ylabel('Deg');
grid;